@@ -1,12 +1,12 @@
 package Module::Loader;
-$Module::Loader::VERSION = '0.01';
+$Module::Loader::VERSION = '0.02';
 use 5.006;
 use Moo;
 use Path::Iterator::Rule;
 use File::Spec::Functions   qw/ catfile splitdir /;
 use Carp                    qw/ croak /;
 
-has 'max_depth' => (is => 'rw');
+has 'max_depth' => (is => 'rw', clearer => 1);
 
 sub find_modules
 {
@@ -35,6 +35,25 @@ sub find_modules
     return keys(%modules);
 }
 
+sub search
+{
+    my $self      = shift;
+    my $max_depth = $self->max_depth;
+
+    $self->max_depth(1);
+
+    my @modules   =  $self->find_modules(@_);
+
+    if (defined $max_depth) {
+        $self->max_depth($max_depth);
+    }
+    else {
+        $self->clear_max_depth();
+    }
+
+    return @modules;
+}
+
 sub load
 {
     my ($self, @modules) = @_;
@@ -109,6 +128,17 @@ that were found in C<@INC>. For example:
 By default this will find all modules in the given namespace,
 unless you've specified a maximum search depth, as described above.
 
+=head2 search
+
+This is the same as C<find_modules()> above, but it hard-codes the search depth
+to 1. This method is provided for compatibility with M<Mojo::Loader>:
+
+ @plugins = $loader->search('Template::Plugin');
+
+It preserves your current setting of the C<max_depth> attribute,
+in the unlikely event that you want to interleave calls to C<find_modules()>
+and C<search()>.
+
 =head2 load
 
 Takes a module name and tries to load the module.
